@@ -43,7 +43,7 @@ class UrlRewriteNewPCT(object):
         if len(torrent_ids) == 0:
             raise UrlRewritingError('Unable to locate torrent ID from url %s' % url)
         torrent_id = torrent_id_prog.search(torrent_ids[0]).group(1)
-        return 'http://www.pctorrent.com/descargar/index.php?link=descargar/torrent/%s/dummy.html' % torrent_id
+        return 'http://tumejorjuego.com/descargar/index.php?link=descargar/torrent/%s/dummy.html' % torrent_id
 
 @event('plugin.register')
 def register_plugin():
